@@ -2,7 +2,9 @@ var globals_eval =
 [
     [ "a", "globals_eval.html", null ],
     [ "c", "globals_eval_c.html", null ],
+    [ "e", "globals_eval_e.html", null ],
     [ "i", "globals_eval_i.html", null ],
+    [ "p", "globals_eval_p.html", null ],
     [ "q", "globals_eval_q.html", null ],
     [ "r", "globals_eval_r.html", null ],
     [ "s", "globals_eval_s.html", null ],
